import io
import os

import maya.cmds as mc
import maya.mel as mel
from os import path as p
from sys import platform as _platform

def get_os():
    if _platform == "linux" or _platform == "linux2":
        osf = "lin"
    elif _platform == "win32" or _platform == "win64":
        osf = "win"
    else:
        osf = "mac"
    return osf


def get_root_dir():
    import os
    pb = 'PickerBuilder'
    pb_path = ''
    for p in os.environ.get('PYTHONPATH').split(os.path.pathsep):
        if pb in p:
            pb_path = os.path.join(p, pb)
            break
    else:
        user_dir = os.path.expanduser('~')
        if get_os() == 'win':
            if not user_dir.endswith('Documents'):
                user_dir += '/Documents'
        pb_path = os.path.join(user_dir, 'maya', 'scripts', pb)
    return pb_path


root_dir = get_root_dir()


def j(*arg):
    return os.path.join(*arg).replace('\\', '/').replace('//', '/')


def get_import_block(name, func):
    return '''import {m}
{m}.{f}()'''.format(m=name, f=func)


def get_command(_module, func):
    output = io.open(p.dirname(__file__)+'/import_code.py', 'r')
    path_block = ''.join([x for x in output.readlines() if '\''*3 not in x])
    output.close()
    return path_block + get_import_block(_module, func)


def add_menu_pb():
    menuPB = 'PB'
    labelMenu = 'Picker builder'
    # delete menu
    if mc.menu(menuPB, q=1, ex=1):
        # mc.deleteUI(mc.menu(menuJM, l=labelMenu, e=1, dai=1))
        mc.deleteUI(menuPB)
    mc.refresh()

    icon_b = j(root_dir, 'icons', 'logo2.png')
    icon_v = j(root_dir, 'icons', 'PB_a.png')

    MainMayaWindow = mel.eval(
        "global string $gMainWindow; $temp = $gMainWindow;")
    # add menu
    cmd_builder = get_command('main_builder', '_main')
    cmd_viewer = get_command('main_viewer', '_main')
    cmd_macaddress = get_command('main_builder', 'get_macadress')
    customMenu = mc.menu('PB', l=labelMenu, parent=MainMayaWindow)
    mc.menuItem(label="Builder", command=cmd_builder, i=icon_b, parent=customMenu)
    mc.menuItem(label="Viewer", command=cmd_viewer, i=icon_v, parent=customMenu)
    mc.menuItem(divider=1, parent=customMenu)
    mc.menuItem(label="get mac-address", command=cmd_macaddress, parent=customMenu)


def add_icons_pb():
    gShelfTopLevel = mel.eval(
        "global string $gShelfTopLevel; $temp = $gShelfTopLevel;")
    currentShelf = mc.tabLayout(gShelfTopLevel, q=1, st=1)
    icon = j(root_dir, 'icons', 'logo2.png')
    cmd = get_command('main_builder', '_main')
    cmd_mac = get_command('main_builder', 'get_macadress')

    icon_pv = p.join(root_dir, 'icons', 'PB_a.png')
    cmd_pv = get_command('main_viewer', '_main')
    PB = 'Picker Builder'
    PV = 'Picker Viewer'
    new_PB = True
    new_PV = True
    buttons = mc.shelfLayout(currentShelf, q=True, childArray=True)
    for b in buttons or []:
        if 'separator' in b:
            continue
        label = mc.shelfButton(b, q=True, l=True)
        if label == PB:
            new_PB = False
            mc.shelfButton(b, e=1,
                           annotation=PB,
                           image1=icon,
                           label=PB,
                           command=cmd,
                           mi=["get mac-address", cmd_mac],
                           mip=0)
        elif label == PV:
            new_PV = False
            mc.shelfButton(b, e=1,
                           annotation=PV,
                           image1=icon_pv,
                           label=PV,
                           command=cmd_pv
                           )

    if new_PB:
        mc.shelfButton(annotation=PB,
                       image1=icon,
                       label=PB,
                       command=cmd,
                       p=currentShelf,
                       mi=["get mac-address", cmd_mac],
                       mip=0)
    if new_PV:
        mc.shelfButton(annotation=PV,
                       image1=icon_pv,
                       label=PV,
                       command=cmd_pv,
                       p=currentShelf)


def load_shelf_pb():
    dest = 'shelf_PickerBuilder.mel'
    if mc.shelfLayout('PickerBuilder', exists=True):
        return

    cmd = 'loadNewShelf ("' + dest + '")'
    mel.eval(cmd)
    # try:
    #     mel.eval(cmd)
    # except:
    #     cmdDel = 'deleteUI -layout ($gShelfTopLevel + "|PickerBuilder")'
    #     mel.eval(cmdDel)
    #     mel.eval(cmd)

    # mc.saveShelf('PickerBuilder', dest)